@@ -30,18 +30,23 @@ get.node.attr <- function(nw, attrname, functionname=NULL, numeric=FALSE) {
     functionname <- ifelse (is.null(functionname), "unknown function",
                         sub('.*[.]', '', functionname)) # truncate up to last '.'
   }
-  if (!is.character(attrname) || length(attrname)>1)
+  if (!is.character(attrname) || length(attrname)>1){
     stop(paste("The argument", attrname, "passed to", functionname,
                "must be a single character string naming a nodal attribute."),
          call.=FALSE)
+  }
   #We'll assume that every vertex must have a value, so checking the 
-  #first is reasonable.
+  #first is reasonable.  #skye:  I think this is not a correct assumption
 	
-  if(NVL(get.network.attribute(nw,"bipartite"),FALSE))	
-  if (!any(attrname==unique(unlist(lapply(nw$val,names)))))
-    stop(paste("Attribute", attrname, "named in", functionname,
-               "model term is not contained in vertex attribute list."),
+  if(NVL(get.network.attribute(nw,"bipartite"),FALSE)){}  
+  # not sure what this code above was supposed to do, but it was only checking if the attribute existed if the network	was bipartite
+  # maybe, if it was bipartite, it should check if appropriate values exist for the mode in question? and should use 'is.bipartite()' for the check
+  
+  if (!any(attrname==unique(unlist(lapply(nw$val,names))))){
+    stop(paste("Attribute '", attrname, "' named in", functionname,
+               "model term is not a vertex attribute  of the network."),
          call.=FALSE)
+  }
   #"[["(nw$val,attrname)
   out <- unlist(get.vertex.attribute(nw,attrname))
   if(numeric && !is.numeric(out)) {
